Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(196)

Unified Diff: gm/rebaseline_server/compare_to_expectations_test.py

Issue 215503002: rebaseline_server: add --compare-configs option (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: rebase Created 6 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « gm/rebaseline_server/compare_to_expectations.py ('k') | gm/rebaseline_server/results.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: gm/rebaseline_server/compare_to_expectations_test.py
diff --git a/gm/rebaseline_server/compare_to_expectations_test.py b/gm/rebaseline_server/compare_to_expectations_test.py
index c0bf19003f6c86f0ad0bf9bf3feeb02fdc3b0453..76e4a7bb3281777e77a90d161a5fdea7c9cb62ad 100755
--- a/gm/rebaseline_server/compare_to_expectations_test.py
+++ b/gm/rebaseline_server/compare_to_expectations_test.py
@@ -31,8 +31,8 @@ import gm_json # must import results first, so that gm_json will be in sys.path
class CompareToExpectationsTest(base_unittest.TestCase):
def test_gm(self):
- """Process results of a GM run with the Results object."""
- results_obj = compare_to_expectations.Results(
+ """Process results of a GM run with the ExpectationComparisons object."""
+ results_obj = compare_to_expectations.ExpectationComparisons(
actuals_root=os.path.join(self._input_dir, 'gm-actuals'),
expected_root=os.path.join(self._input_dir, 'gm-expectations'),
generated_images_root=self._temp_dir,
@@ -45,7 +45,7 @@ class CompareToExpectationsTest(base_unittest.TestCase):
def mock_get_timestamp():
"""Mock version of Results.get_timestamp() for testing."""
return 12345678
« no previous file with comments | « gm/rebaseline_server/compare_to_expectations.py ('k') | gm/rebaseline_server/results.py » ('j') | no next file with comments »
@@ -45,7 +45,7 @@ class CompareToExpectationsTest(base_unittest.TestCase):
def mock_get_timestamp():
- """Mock version of Results.get_timestamp() for testing."""
+ """Mock version of BaseComparisons.get_timestamp() for testing."""
return 12345678
« no previous file with comments | « gm/rebaseline_server/compare_to_expectations.py ('k') | gm/rebaseline_server/results.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698